/*
 *   Copyright 2007 Alex Merry <alex.merry@kdemail.net>
 *
 *   Based on Xmms support in the Kopete Now Listening plugin
 *   Copyright 2002 by Will Stephenson <will@stevello.free-online.co.uk>
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU Library General Public License version 2 as
 *   published by the Free Software Foundation
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details
 *
 *   You should have received a copy of the GNU Library General Public
 *   License along with this program; if not, write to the
 *   Free Software Foundation, Inc.,
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

#include "xmms.h"

#include <kdebug.h>

#include <xmmsctrl.h>


Xmms::Xmms(QObject* parent)
    : QObject(parent)
{
}

Xmms::~Xmms()
{
}

QString Xmms::name()
{
    return "XMMS";
}

bool Xmms::isRunning()
{
    return xmms_remote_is_running(0);
}

Player::State Xmms::state()
{
    if (xmms_remote_is_paused(0)) {
        return Paused;
    } else if (xmms_remote_is_playing(0)) {
        return Playing;
    }
    return Stopped;
}

QString Xmms::artist()
{
    // let's hope no-one changes the default title string
    QString track = xmms_remote_get_playlist_title(0, xmms_remote_get_playlist_pos(0));
    return track.section(" - ", 0, 0);
}

QString Xmms::album()
{
    return QString();
}

QString Xmms::title()
{
    // let's hope no-one changes the default title string
    QString track = xmms_remote_get_playlist_title(0, xmms_remote_get_playlist_pos(0));
    return track.section(" - ", -1, -1);
}

int Xmms::trackNumber()
{
    // we can get the playlist pos, but that's not what we mean by "trackNumber"
    return 0;
}

QString Xmms::comment()
{
    return QString();
}

QString Xmms::genre()
{
    return QString();
}

int Xmms::length()
{
    return xmms_remote_get_playlist_time(0, xmms_remote_get_playlist_pos(0));
}

int Xmms::position()
{
    return xmms_remote_get_output_time(0);
}

float Xmms::volume()
{
    return xmms_remote_get_main_volume(0);
}

void Xmms::play()
{
    xmms_remote_play(0);
}

void Xmms::pause()
{
    xmms_remote_pause(0);
}

void Xmms::stop()
{
    xmms_remote_stop(0);
}

void Xmms::previous()
{
    xmms_remote_playlist_prev(0);
}

void Xmms::next()
{
    xmms_remote_playlist_next(0);
}

void Xmms::setVolume(float volume)
{
    xmms_remote_set_main_volume(0, volume);
}

void Xmms::seek(int time)
{
    xmms_remote_jump_to_time(0, time);
}


#include "xmms.moc"
